summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorMaxime Coste <mawww@kakoune.org>2017-10-13 13:09:33 +0800
committerMaxime Coste <mawww@kakoune.org>2017-11-01 14:05:14 +0800
commitdf16fea82d4fec38357773596a9557b4dffc053c (patch)
tree3b5fecfb4e4fb74d9cddb552be823c0ce072bc18 /src
parent52d443f764eb918b184328c75c49ebefa87c6793 (diff)
Regex: rename "flags" with the more common "modifiers"
Diffstat (limited to 'src')
-rw-r--r--src/regex_impl.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/regex_impl.cc b/src/regex_impl.cc
index 4742a47a..43b0d818 100644
--- a/src/regex_impl.cc
+++ b/src/regex_impl.cc
@@ -135,7 +135,7 @@ private:
AstNodePtr term()
{
- while (flag()) // read all flags
+ while (modifiers()) // read all modifiers
{}
if (auto node = assertion())
return node;
@@ -158,7 +158,7 @@ private:
return true;
}
- bool flag()
+ bool modifiers()
{
if (peek("(?i)"))
{